--- curl-7.12-hostip4/lib/inet_ntop.c	Thu Apr 22 16:15:30 2004
+++ inet_ntop.c	Fri Apr 23 12:45:21 2004
@@ -146,7 +146,7 @@
       tp += strlen(tp);
       break;
     }
-    tp += sprintf (tp, "%lX", words[i]);
+    tp += sprintf (tp, "%lx", words[i]);
   }

   /* Was it a trailing run of 0x00's?


--- curl-7.12-hostip4/lib/hostthre.c	Thu Apr 22 21:45:41 2004
+++ hostthre.c	Fri Apr 23 13:13:32 2004
@@ -175,8 +175,8 @@

 #if defined(CURLRES_IPV4)
 /*
  * gethostbyname_thread() resolves a name, calls the Curl_host_callback and
  * then exits.
  *
  * For builds without ARES/ENABLE_IPV6, create a resolver thread and wait on
  * it.
@@ -188,16 +188,20 @@
   struct hostent *he;
   int    rc;

+  /* Sharing the same _iob[] element with our parent thread should
+   * hopefully make printouts synchronised. I'm not sure it works
+   * with a static runtime lib (MSVC's libc.lib).
+   */
   *stderr = *td->stderr_file;

   WSASetLastError (conn->async.status = NO_DATA); /* pending status */
   he = gethostbyname (conn->async.hostname);
   if (he) {
-    Curl_host_callback(conn, CURL_ASYNC_SUCCESS, he);
+    Curl_addrinfo_callback(conn, CURL_ASYNC_SUCCESS, he);
     rc = 1;
   }
   else {
-    Curl_host_callback(conn, (int)WSAGetLastError(), NULL);
+    Curl_addrinfo_callback(conn, (int)WSAGetLastError(), NULL);
     rc = 0;
   }
   TRACE(("Winsock-error %d, addr %s\n", conn->async.status,
@@ -238,7 +242,7 @@
     Curl_addrinfo_callback(conn, CURL_ASYNC_SUCCESS, res);
   }
   else {
-    getaddrinfo_callback(conn, (int)WSAGetLastError(), NULL);
+    Curl_addrinfo_callback(conn, (int)WSAGetLastError(), NULL);
     TRACE(("Winsock-error %d, no address\n", conn->async.status));
   }
   return (rc);
@@ -353,7 +357,7 @@
   status = WaitForSingleObject(td->thread_hnd, 1000UL*timeout);
   if (status == WAIT_OBJECT_0 || status == WAIT_ABANDONED) {
      /* Thread finished before timeout; propagate Winsock error to this thread.
       * 'conn->async.done = TRUE' is set in Curl_host_callback().
       */
      WSASetLastError(conn->async.status);
      GetExitCodeThread(td->thread_hnd, &td->thread_status);
@@ -540,7 +544,7 @@
   }

   /* fall-back to blocking version */
-  infof(data, "Curl_init_resolve_thread() failed for %s; code %lu\n",
+  infof(data, "init_resolve_thread() failed for %s; code %lu\n",
         hostname, GetLastError());

   error = getaddrinfo(hostname, sbuf, &hints, &res);
@@ -175,8 +175,8 @@
 #if defined(CURLRES_IPV4)
 /*
- * gethostbyname_thread() resolves a name, calls the Curl_host_callback and
- * then exits.
+ * gethostbyname_thread() resolves a name, calls the Curl_addrinfo_callback
+ * and then exits.
  *
  * For builds without ARES/ENABLE_IPV6, create a resolver thread and wait on
@@ -353,7 +357,7 @@
   if (status == WAIT_OBJECT_0 || status == WAIT_ABANDONED) {
      /* Thread finished before timeout; propagate Winsock error to this thread.
-      * 'conn->async.done = TRUE' is set in Curl_host_callback().
+      * 'conn->async.done = TRUE' is set in Curl_addrinfo_callback().
       */
      WSASetLastError(conn->async.status);